%bcond_with tests

%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           flatbuffers
Version:        1.12.0
Release:        %mkrel 4
Summary:        Memory efficient serialization library
URL:            http://google.github.io/flatbuffers
Group:          Development/Other

# The entire source code is ASL 2.0 except grpc/ which is BSD (3 clause)
License:        ASL 2.0 and BSD

Source0:        https://github.com/google/flatbuffers/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        flatc.1
Source2:        flatbuffers.7

# Upstream bug: https://github.com/google/flatbuffers/issues/5769
Patch2:         0002-Handle-git-program-or-.git-folder-absence-5878.patch

BuildRequires:  cmake >= 2.8.9
BuildRequires:  git-core
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools

# The library contains pieces of gRPC project, with some additions.
# It is not easy to identify the version, which was used to take the code,
# but it should be something after version 1.3.2. See this discussion for
# details: https://github.com/google/flatbuffers/pull/4305
Provides:       bundled(grpc)

%description
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{libname}
Summary:        Memory efficient serialization library
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Conflicts:      %{name} < 1.9.0-3

%description -n %{libname}
FlatBuffers is a serialization library for games and other memory constrained
apps. FlatBuffers allows you to directly access serialized data without
unpacking/parsing it first, while still having great forwards/backwards
compatibility.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < 1.9.0-3

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%package -n     python3-%{name}
Summary:        Python3 bindings for %{name}
Group:          Development/Python
BuildArch:      noarch
Requires:       %{name} >= %{version}-%{release}

%description -n python3-%{name}
This package contains python 3 bindings for %{name}.

#------------------------------------------------

%prep
%autosetup -p1
# cleanup distribution
rm -rf js net php docs go java js biicode {samples/,}android
chmod -x readme.md

%build
%cmake -DCMAKE_BUILD_TYPE=Release \
       -DFLATBUFFERS_BUILD_SHAREDLIB=ON \
       -DFLATBUFFERS_BUILD_FLATLIB=OFF \
       -DFLATBUFFERS_BUILD_FLATC=ON \
       -DFLATBUFFERS_BUILD_TESTS=%{?with_tests:ON}%{!?with_tests:OFF}

%cmake_build

pushd python
%py3_build
popd

%install
%cmake_install

pushd python
%py3_install
popd

mkdir -p %{buildroot}%{_mandir}/man{1,7}
cp -p %{SOURCE1} %{buildroot}%{_mandir}/man1/flatc.1
cp -p %{SOURCE2} %{buildroot}%{_mandir}/man7/flatbuffers.7

%check
%if %{with tests}
%__make test -C %{_vpath_builddir}
%endif

%files
%license LICENSE.txt
%doc readme.md
%{_bindir}/flatc
%{_mandir}/man1/flatc.1*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_mandir}/man7/%{name}.7*
%{_libdir}/cmake/%{name}/

%files -n python3-%{name}
%{python3_sitelib}/*


%changelog
* Mon Aug 10 2020 neoclust <neoclust> 1.12.0-4.mga8
+ Revision: 1613087
- Rebuild because of wrong rpm preventing hdlist generation

* Mon Aug 10 2020 daviddavid <daviddavid> 1.12.0-3.mga8
+ Revision: 1613061
- make python3 sub-pkg noarch

* Mon Aug 10 2020 daviddavid <daviddavid> 1.12.0-2.mga8
+ Revision: 1613047
- enable python3 module

* Tue Jun 23 2020 daviddavid <daviddavid> 1.12.0-1.mga8
+ Revision: 1598873
- new version: 1.12.0
- fix illegal version in CMake/FlatbuffersConfigVersion.cmake.in
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Jul 05 2019 daviddavid <daviddavid> 1.11.0-1.mga8
+ Revision: 1418681
- new version: 1.11.0

* Wed Oct 31 2018 daviddavid <daviddavid> 1.10.0-1.mga7
+ Revision: 1326822
- new version: 1.10.0

* Sun Sep 23 2018 umeabot <umeabot> 1.9.0-4.mga7
+ Revision: 1297719
- Mageia 7 Mass Rebuild

* Mon Aug 20 2018 daviddavid <daviddavid> 1.9.0-3.mga7
+ Revision: 1253010
- libify lib and devel sub-pkgs

* Sun Aug 19 2018 neoclust <neoclust> 1.9.0-2.mga7
+ Revision: 1252882
- imported package flatbuffers


* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Apr 06 2018 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.9.0-1
- Update to 1.9.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb 03 2018 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-3
- Fix build errors.

* Wed Nov 22 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-2
- Update manpages for 1.8.0

* Wed Nov 22 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.8.0-1
- Update to 1.8.0

* Thu Nov 2 2017 Sergey Avseyev <sergey.avseyev@gmail.com> - 1.7.1-1
- Initial version

* Mon Mar 30 2015 Daniel Vrátil <dvratil@redhat.com> - 1.0.3-1
- Initial version (abandoned at #1207208)
